package com.xxfc.platform.order.biz;


import com.github.wxiaoqi.security.admin.entity.AppUserLogin;
import com.github.wxiaoqi.security.admin.feign.UserFeign;
import com.github.wxiaoqi.security.common.biz.BaseBiz;
import com.github.wxiaoqi.security.common.vo.PageDataVO;
import com.xxfc.platform.order.entity.OrderActivityDetail;;
import com.xxfc.platform.order.mapper.OrderActivityDetailMapper;
import com.xxfc.platform.order.pojo.dto.ActivityOrderFindDTO;
import com.xxfc.platform.order.pojo.vo.OrderActivityInfoStaticVo;
import com.xxfc.platform.order.pojo.vo.OrderActivityInfoVo;
import io.swagger.annotations.Api;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;
import tk.mybatis.mapper.entity.Example;

import java.util.*;
import java.util.stream.Collectors;

@Service
@Slf4j
@Api("活动订单详情")
public class OrderActivityInfoDetailBiz extends BaseBiz<OrderActivityDetailMapper, OrderActivityDetail> {


    @Autowired
    UserFeign userFeign;


    public  OrderActivityDetail getOne(Integer orderId) {
        Example example = new Example(OrderActivityDetail.class);
        example.createCriteria().andEqualTo("orderId", orderId);
        return mapper.selectOneByExample(example);
    }


    public List<OrderActivityInfoVo> getList(ActivityOrderFindDTO activityOrderFindDTO){
        return  mapper.selectList(activityOrderFindDTO);
    }



    public PageDataVO<OrderActivityInfoVo> selectList(ActivityOrderFindDTO activityOrderFindDTO) {
        PageDataVO<OrderActivityInfoVo> dataVO = new PageDataVO<>();
        dataVO.setPageNum(activityOrderFindDTO.getPage());
        dataVO.setPageSize(activityOrderFindDTO.getLimit());
        dataVO.setData(Collections.EMPTY_LIST);
        List<AppUserLogin> parentUserLogins = null;
        if (StringUtils.isNotEmpty(activityOrderFindDTO.getLeaderPhone())) {
            parentUserLogins = userFeign.getOne(activityOrderFindDTO.getLeaderPhone(),null);
            if (parentUserLogins  ==  null || parentUserLogins.size() == 0 )
                return dataVO;
            List<Integer> userIds = parentUserLogins.stream().map(AppUserLogin::getId).distinct().collect(Collectors.toList());
            activityOrderFindDTO.setParentUserIds(userIds);
        }
        List<AppUserLogin> userLogins = null;
        if (StringUtils.isNotEmpty(activityOrderFindDTO.getName()) || StringUtils.isNotEmpty(activityOrderFindDTO.getPhone())) {
            userLogins = userFeign.getOne(activityOrderFindDTO.getPhone(),activityOrderFindDTO.getName());
            if (userLogins  ==  null || userLogins.size() == 0 )
                return dataVO;
            List<Integer> userIds = userLogins.stream().map(AppUserLogin::getId).distinct().collect(Collectors.toList());
            activityOrderFindDTO.setUserIds(userIds);
        }
        dataVO = PageDataVO.pageInfo(activityOrderFindDTO.getPage(), activityOrderFindDTO.getLimit(), () -> getList(activityOrderFindDTO));
        List<OrderActivityInfoVo> data = dataVO.getData();
        if (CollectionUtils.isEmpty(data)) {
            return dataVO;
        }
        Map<Integer, AppUserLogin> parentUserLoginMap = new HashMap<>();
        if (parentUserLogins == null ) {
            List<Integer> userIds = data.stream().map(OrderActivityInfoVo::getParentUserId).distinct().collect(Collectors.toList());
            parentUserLoginMap = userFeign.findAppUsersByUserIds(userIds);
        }else {
            for (AppUserLogin appUserLogin : parentUserLogins){
                parentUserLoginMap.put(appUserLogin.getId(),appUserLogin);
            }
        }

        Map<Integer, AppUserLogin> userLoginMap = new HashMap<>();
        if (userLogins == null ) {
            List<Integer> userIds = data.stream().map(OrderActivityInfoVo::getUserId).distinct().collect(Collectors.toList());
            userLoginMap = userFeign.findAppUsersByUserIds(userIds);
        }else {
            for (AppUserLogin appUserLogin : userLogins){
                userLoginMap.put(appUserLogin.getId(),appUserLogin);
            }
        }

        for (OrderActivityInfoVo orderActivityInfoVo : data) {
             if (orderActivityInfoVo.getParentUserId() != null ){
                 AppUserLogin userLogin = parentUserLoginMap.get(orderActivityInfoVo.getParentUserId());
                 if (userLogin != null ){
                     orderActivityInfoVo.setParentPhone(userLogin.getUsername());
                     orderActivityInfoVo.setParentName(userLogin.getRealname());
                 }
             }
             AppUserLogin userLogin = userLoginMap.get(orderActivityInfoVo.getUserId());
             if (userLogin != null ){
                 orderActivityInfoVo.setPhone(userLogin.getUsername());
                 orderActivityInfoVo.setRealName(userLogin.getRealname());
             }
        }
        return dataVO;
    }


    public OrderActivityInfoStaticVo selectListStatic(ActivityOrderFindDTO activityOrderFindDTO) {
        OrderActivityInfoStaticVo orderActivityInfoStaticVo = new OrderActivityInfoStaticVo();
        List<AppUserLogin> parentUserLogins = null;
        if (StringUtils.isNotEmpty(activityOrderFindDTO.getLeaderPhone())) {
            parentUserLogins = userFeign.getOne(activityOrderFindDTO.getLeaderPhone(),null);
            if (parentUserLogins  ==  null || parentUserLogins.size() == 0 )
                return orderActivityInfoStaticVo;
            List<Integer> userIds = parentUserLogins.stream().map(AppUserLogin::getId).distinct().collect(Collectors.toList());
            activityOrderFindDTO.setParentUserIds(userIds);
        }
        List<AppUserLogin> userLogins = null;
        if (StringUtils.isNotEmpty(activityOrderFindDTO.getName()) || StringUtils.isNotEmpty(activityOrderFindDTO.getPhone())) {
            userLogins = userFeign.getOne(activityOrderFindDTO.getPhone(),activityOrderFindDTO.getName());
            if (userLogins  ==  null || userLogins.size() == 0 )
                return orderActivityInfoStaticVo;
            List<Integer> userIds = userLogins.stream().map(AppUserLogin::getId).distinct().collect(Collectors.toList());
            activityOrderFindDTO.setUserIds(userIds);
        }
        orderActivityInfoStaticVo = getListStatic(activityOrderFindDTO);
        return orderActivityInfoStaticVo;
    }


    public  OrderActivityInfoStaticVo  getListStatic(ActivityOrderFindDTO activityOrderFindDTO){
        return  mapper.selectListStatic(activityOrderFindDTO);
    }



}
